/*
*******************************************************************************
* File:         E5270_TIS.h
* Description:  E5270A TIS Library header file
* Revisions:    A.01.01   [ 1/1/2003 ]
* Language:     C
*
* (C) Copyright 2003, Agilent Technologies Company, all rights reserved.
*******************************************************************************
*/

#ifndef E5270_TIS_H
#define E5270_TIS_H

#include <string.h> 
#include "age5270.h"

#ifdef __cplusplus
extern "C" {
#endif

#define ERR_DETECT_ON                 1
#define ERR_DETECT_OFF                0

#define REMAIN                9.99999999e30

#define INTEG_MANUAL                  0
#define INTEG_SHORT                   1
#define INTEG_MEDIUM                  2
#define INTEG_LONG                    3

#define V_SOURCE                      1
#define I_SOURCE                      2

#define V_MEAS                        1
#define I_MEAS                        2

#define OFF                           0
#define ON                            1

#define SMU1          20001
#define SMU2          20002
#define SMU3          20003
#define SMU4          20004
#define SMU5          20005
#define SMU6          20006
#define SMU7          20007
#define SMU8          20008
#define GNDU          20009


#define NORMAL_MEAS             0
#define DCS_COMP_OTHER          1
#define DCS_COMP                2
#define DCS_OSC                 3
#define DCS_OVERFLOW            4
#define DCS_SWP_STOPPED         5
#define DCS_BDV_NORMAL          0
#define DCS_BDV_COMP_OTHER      1
#define DCS_BDV_CURRENT_LOW     2
#define DCS_BDV_OSC             3
#define DCS_BDV_OVERFLOW        4
#define DCS_BDV_TIMEOUT         6
#define DCS_BDV_TOO_SLOW        7

/* set_smu */
#define PERCH_ADC      0
#define REF_ADC        1
#define FILTER_OFF     0
#define FILTER_ON      1
#define INTEG_MANUAL   0
#define INTEG_SHORT    1
#define INTEG_MEDIUM   2
#define INTEG_LONG     3
#define AUTOZERO_OFF   0
#define AUTOZERO_ON    1


/* Measure */
#define V_MEAS         1
#define I_MEAS         2

/* Set_iv */
#define LINEAR_V        1
#define LINEAR_I        2
#define LOG_V          -1
#define LOG_I          -2
#define LINEAR_V_DBL    3
#define LINEAR_I_DBL    4
#define LOG_V_DBL      -3
#define LOG_I_DBL      -4
#define COMP_CONT       1
#define COMP_STOP       2

/* Set_sync */
#define POS_SYNC        0
#define NEG_SYNC        1

/* Measure_bdv */
#define BDV_NORMAL        0
#define BDV_COMP_OTHER    1
#define BDV_CURRENT_LOW   2
/* #define BDV_OCS           3 */
#define BDV_OSC           3
#define BDV_OVERFLOW      4
#define BDV_TIMEOUT       6
#define BDV_TOO_SLOW      7
#define BDV_INTVL_SHORT   0
#define BDV_INTVL_LONG    1

/* Measure_ileak */
#define ILEAK_NORMAL        0
#define ILEAK_COMP_OTHER    1
#define ILEAK_COMP          2
/* #define ILEAK_OCS           3 */
#define ILEAK_OSC           3
#define ILEAK_OVERFLOW      4
#define ILEAK_TIMEOUT       6
#define ILEAK_TOO_SLOW      7
#define ILEAK_INTVL_SHORT   0
#define ILEAK_INTVL_LONG    1


/*== 4070 TIS incompatible functions =========================================*/
extern int open_E5270( char *instr_desc, int err_query, char *log_file );
extern int close_E5270( void );
extern ViSession vi_E5270( void );

/*== 4070 TIS compatible functions =========================================*/
extern int init_system( void );
extern int set_adc( int adc, int mode, double value, int autozero );
extern int reset_timestamp( void );
extern int set_timestamp( int on_off );
extern int connect_pin( int port, int pin );
extern int disconnect_all( void );
extern int disable_port( int port );
extern int set_smu_ch( int port, int adc, int filter );
extern int force_v( int port, double voltage, double range, double compliance );
extern int force_i( int port, double current, double range, double compliance );
extern int set_iv( int port, int sweep_mode, double range, double start, double stop,
                      int number, double hold, double delay, 
                      double compliance, double power_compliance, int stop_mode );
extern int set_piv( int port, int sweep_mode, double range, 
                      double base, double start, double stop,
                      int number, double width, double period, double hold,
                      double compliance, int stop_mode );
extern int set_pbias( int port, int mode, double range, double base, double peak, 
                      double width, double period, double hold, double compliance );
extern int set_sync( int port, int mode, double offset, double ratio, 
                      double compliance, double power_compliance );
extern int measure_v( int port, double *voltage, double range );
extern int measure_i( int port, double *current, double range );
extern int measure_vt( int port, double *voltage, double range, double *time_stamp );
extern int measure_it( int port, double *current, double range, double *time_stamp );
extern int measure_m( int n, int *ports, double *meas_vals, double *ranges, 
                      double *time_stamps );
extern int measure_p( int port,  int mode, double *value, double range );
extern int port_status( int port, int *status );
extern int port_status_t( int port, int *status, double *time_stamp );
extern int sweep_iv( int port, int mode, double range, 
                      double *measure, double *source, double *sync );
extern int sweep_miv( int n, int *ports, double *ranges, 
                      double *meas_vals, double *source, double *sync );
extern int status_miv( int n, int *ports, int *statuses, double *times );
extern int set_bdv( int port, double range, double start, double stop, double current, 
                    double hold, double delay );
extern int measure_bdv( double *voltage, int *status, int interval );
extern int set_ileak( int port, double range, double voltage, double compliance, 
                      double start, double hold, double delay );
extern int measure_ileak( int port, double *current, int *status, int interval );
extern int error_info( int *errn, char *errm );

#ifdef __cplusplus
}
#endif

#endif     /* E5270_TIS_H */
